@@ -1,7 +1,7 @@
 """
 Type annotations for emr-containers service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/literals/)
 
 Usage::
 
@@ -29,8 +29,11 @@ __all__ = (
     "ListVirtualClustersPaginatorName",
     "PersistentAppUIType",
     "VirtualClusterStateType",
+    "EMRContainersServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -49,6 +52,7 @@ ListManagedEndpointsPaginatorName = Literal["list_managed_endpoints"]
 ListVirtualClustersPaginatorName = Literal["list_virtual_clusters"]
 PersistentAppUIType = Literal["DISABLED", "ENABLED"]
 VirtualClusterStateType = Literal["ARRESTED", "RUNNING", "TERMINATED", "TERMINATING"]
+EMRContainersServiceName = Literal["emr-containers"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -337,4 +341,34 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["list_job_runs", "list_managed_endpoints", "list_virtual_clusters"]
+RegionName = Literal[
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
